@@ -9,9 +9,14 @@ use Exporter qw(import);
 
 our $foo = ("buggyd");
 our %goo = ("lexical" => "awfulhak");
+our @roo = (\%goo, sub { return \$foo; });
 
 return 1;
 
+sub closure {
+    return sub { return \@roo; };
+}
+
 sub foo {
     my $self = shift;
     return $self->SUPER::foo . " $foo";
